# Zetic CLI

On-device model converter service.

## Guide

### 1. Auth

```bash
# login with zetic
zetic auth login

# If you have no brwoser
zetic auth login --no-browser
```


### 2. Upload model

```bash

# login with zetic

zetic gen path/to/model --input path/to/input.npy --input path/to/input2.py
```
